package com.ruoyi.cs.mapper;

import java.util.List;
import com.ruoyi.cs.domain.CsMemberNotice;

/**
 * 用户弹窗公告记录Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-15
 */
public interface CsMemberNoticeMapper 
{
    /**
     * 查询用户弹窗公告记录
     * 
     * @param memberNoticeId 用户弹窗公告记录主键
     * @return 用户弹窗公告记录
     */
    public CsMemberNotice selectCsMemberNoticeByMemberNoticeId(Integer memberNoticeId);

    /**
     * 查询用户弹窗公告记录列表
     * 
     * @param csMemberNotice 用户弹窗公告记录
     * @return 用户弹窗公告记录集合
     */
    public List<CsMemberNotice> selectCsMemberNoticeList(CsMemberNotice csMemberNotice);

    /**
     * 新增用户弹窗公告记录
     * 
     * @param csMemberNotice 用户弹窗公告记录
     * @return 结果
     */
    public int insertCsMemberNotice(CsMemberNotice csMemberNotice);

    /**
     * 修改用户弹窗公告记录
     * 
     * @param csMemberNotice 用户弹窗公告记录
     * @return 结果
     */
    public int updateCsMemberNotice(CsMemberNotice csMemberNotice);

    /**
     * 删除用户弹窗公告记录
     * 
     * @param memberNoticeId 用户弹窗公告记录主键
     * @return 结果
     */
    public int deleteCsMemberNoticeByMemberNoticeId(Integer memberNoticeId);

    /**
     * 批量删除用户弹窗公告记录
     * 
     * @param memberNoticeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCsMemberNoticeByMemberNoticeIds(Integer[] memberNoticeIds);
}
