package com.ruoyi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.cs.domain.CsMemberNotice;
import com.ruoyi.cs.service.ICsMemberNoticeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户弹窗公告记录Controller
 *
 * @author ruoyi
 * @date 2024-08-15
 */
@RestController
@RequestMapping("/cs/csMemberNotice")
public class CsMemberNoticeController extends BaseController
{
    @Autowired
    private ICsMemberNoticeService csMemberNoticeService;

    /**
     * 查询用户弹窗公告记录列表
     */
    @PreAuthorize("@ss.hasPermi('cs:csMemberNotice:list')")
    @GetMapping("/list")
    public TableDataInfo list(CsMemberNotice csMemberNotice)
    {
        startPage();
        List<CsMemberNotice> list = csMemberNoticeService.selectCsMemberNoticeList(csMemberNotice);
        return getDataTable(list);
    }

    /**
     * 导出用户弹窗公告记录列表
     */
    @PreAuthorize("@ss.hasPermi('cs:csMemberNotice:export')")
    @Log(title = "用户弹窗公告记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CsMemberNotice csMemberNotice)
    {
        List<CsMemberNotice> list = csMemberNoticeService.selectCsMemberNoticeList(csMemberNotice);
        ExcelUtil<CsMemberNotice> util = new ExcelUtil<CsMemberNotice>(CsMemberNotice.class);
        util.exportExcel(response, list, "用户弹窗公告记录数据");
    }

    /**
     * 获取用户弹窗公告记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('cs:csMemberNotice:query')")
    @GetMapping(value = "/{memberNoticeId}")
    public AjaxResult getInfo(@PathVariable("memberNoticeId") Integer memberNoticeId)
    {
        return AjaxResult.success(csMemberNoticeService.selectCsMemberNoticeByMemberNoticeId(memberNoticeId));
    }

    /**
     * 新增用户弹窗公告记录
     */
    @PreAuthorize("@ss.hasPermi('cs:csMemberNotice:add')")
    @Log(title = "用户弹窗公告记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CsMemberNotice csMemberNotice)
    {
        return toAjax(csMemberNoticeService.insertCsMemberNotice(csMemberNotice));
    }

    /**
     * 修改用户弹窗公告记录
     */
    @PreAuthorize("@ss.hasPermi('cs:csMemberNotice:edit')")
    @Log(title = "用户弹窗公告记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CsMemberNotice csMemberNotice)
    {
        return toAjax(csMemberNoticeService.updateCsMemberNotice(csMemberNotice));
    }

    /**
     * 删除用户弹窗公告记录
     */
    @PreAuthorize("@ss.hasPermi('cs:csMemberNotice:remove')")
    @Log(title = "用户弹窗公告记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{memberNoticeIds}")
    public AjaxResult remove(@PathVariable Integer[] memberNoticeIds)
    {
        return toAjax(csMemberNoticeService.deleteCsMemberNoticeByMemberNoticeIds(memberNoticeIds));
    }
}
